Package: ggrounded
Title: Rounded Bar Plots
Version: 0.2.0
Authors@R: 
    person("Botan", "Ağın", , "aginbotan@gmail.com", role = c("aut", "cre", "cph"))
Author: Botan Ağın [aut, cre, cph]
Maintainer: Botan Ağın <aginbotan@gmail.com>
Description: Creates bar plots with rounded corners using 'ggplot2'.
    The code in this package was adapted from a solution provided by 
    Stack Overflow user 'sthoch' in the following post
    <https://stackoverflow.com/questions/62176038/r-ggplot2-bar-chart-with-round-corners-on-top-of-bar>.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
Imports: ggplot2, grid
URL: https://github.com/botan/ggrounded,
        https://botan.github.io/ggrounded/
BugReports: https://github.com/botan/ggrounded/issues
Suggests: covr, testthat (>= 3.0.0), vdiffr
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-30 20:53:46 UTC; botan
Repository: CRAN
Date/Publication: 2026-05-01 06:20:02 UTC
Built: R 4.4.3; ; 2026-05-01 13:51:59 UTC; unix
